@@ -29,7 +29,8 @@ KEYPOINT_CONNECTORS_BY_POSE_MODEL = {
     'MPII-15': [[0, 1], [1, 14], [14, 2], [2, 3], [3, 4], [14, 5], [5, 6], [6, 7], [14, 8], [8, 9], [9, 10], [14, 11], [11, 12], [12, 13]],
     'MPII-16': [[6, 7], [7, 8], [8, 9], [6, 2], [2, 1], [1, 0], [6, 3], [3, 4], [4, 5], [8, 12], [12, 11], [11, 10], [8, 13], [13, 14], [14, 15]],
     'BODY_25': [[2, 3], [3, 4], [5, 2], [5, 6], [6, 7], [0, 1], [0, 15], [0, 16], [1, 2], [1, 5], [15, 17], [16, 18], [1, 8], [8, 9], [9, 10], [10, 11], [11, 24], [24, 22], [24, 23], [8, 12], [12, 13], [13, 14], [14, 21], [21, 19], [21, 20]],
-    'BLAZEPOSE': [[8, 6], [6, 5], [5, 4], [4, 0], [0, 1], [1, 2], [2, 3], [3, 7], [10, 9], [16, 18], [18, 20], [20, 16], [16, 22], [16, 14], [14, 12], [15, 17], [17, 19], [19, 15], [15, 21], [15, 13], [13, 11], [12, 11], [12, 24], [11, 23], [24, 23], [24, 26], [26, 28], [28, 32], [32, 30], [30, 28], [23, 25], [25, 27], [27, 31], [31, 29], [29, 27]]
+    'BLAZEPOSE': [[8, 6], [6, 5], [5, 4], [4, 0], [0, 1], [1, 2], [2, 3], [3, 7], [10, 9], [16, 18], [18, 20], [20, 16], [16, 22], [16, 14], [14, 12], [15, 17], [17, 19], [19, 15], [15, 21], [15, 13], [13, 11], [12, 11], [12, 24], [11, 23], [24, 23], [24, 26], [26, 28], [28, 32], [32, 30], [30, 28], [23, 25], [25, 27], [27, 31], [31, 29], [29, 27]],
+    'HALPE-26': [[17, 18], [18, 19], [17, 0], [17, 1], [17, 2], [17, 3], [17, 4], [18, 5], [5, 7], [7, 9], [18, 6], [6, 8], [8, 10], [19, 11], [11, 13], [13, 15], [15, 24], [24, 20], [24, 22], [19, 12], [12, 14], [14, 16], [16, 25], [25, 21], [25, 23]]
 }
 
 def overlay_poses_2d(
